@@ -17,8 +17,9 @@
 #include "krecentfilesaction.h"
 #include "krecentfilesaction_p.h"
 
-#include <QFile>
+#include <QActionGroup>
 #include <QDir>
+#include <QFile>
 #include <QGuiApplication>
 #include <QMenu>
 #include <QScreen>
@@ -28,16 +29,16 @@
 #include <KLocalizedString>
 
 KRecentFilesAction::KRecentFilesAction(QObject *parent)
-    : KSelectAction(parent),
-      d_ptr(new KRecentFilesActionPrivate(this))
+    : KSelectAction(parent)
+    , d_ptr(new KRecentFilesActionPrivate(this))
 {
     Q_D(KRecentFilesAction);
     d->init();
 }
 
 KRecentFilesAction::KRecentFilesAction(const QString &text, QObject *parent)
-    : KSelectAction(parent),
-      d_ptr(new KRecentFilesActionPrivate(this))
+    : KSelectAction(parent)
+    , d_ptr(new KRecentFilesActionPrivate(this))
 {
     Q_D(KRecentFilesAction);
     d->init();
@@ -47,8 +48,8 @@ KRecentFilesAction::KRecentFilesAction(const QString &text, QObject *parent)
 }
 
 KRecentFilesAction::KRecentFilesAction(const QIcon &icon, const QString &text, QObject *parent)
-    : KSelectAction(parent),
-      d_ptr(new KRecentFilesActionPrivate(this))
+    : KSelectAction(parent)
+    , d_ptr(new KRecentFilesActionPrivate(this))
 {
     Q_D(KRecentFilesAction);
     d->init();
@@ -74,18 +75,15 @@ void KRecentFilesActionPrivate::init()
     clearAction->setObjectName(QStringLiteral("clear_action"));
     clearAction->setVisible(false);
     q->setEnabled(false);
-    q->connect(q, SIGNAL(triggered(QAction*)), SLOT(_k_urlSelected(QAction*)));
+    q->connect(q, SIGNAL(triggered(QAction *)), SLOT(_k_urlSelected(QAction *)));
 }
 
-KRecentFilesAction::~KRecentFilesAction()
-{
-    delete d_ptr;
-}
+KRecentFilesAction::~KRecentFilesAction() = default;
 
 void KRecentFilesActionPrivate::_k_urlSelected(QAction *action)
 {
     Q_Q(KRecentFilesAction);
-    emit q->urlSelected(m_urls[action]);
+    Q_EMIT q->urlSelected(m_urls[action]);
 }
 
 int KRecentFilesAction::maxItems() const
@@ -98,10 +96,10 @@ void KRecentFilesAction::setMaxItems(int maxItems)
 {
     Q_D(KRecentFilesAction);
     // set new maxItems
-    d->m_maxItems = maxItems;
+    d->m_maxItems = std::max(maxItems, 0);
 
     // remove all excess items
-    while (selectableActionGroup()->actions().count() > maxItems) {
+    while (selectableActionGroup()->actions().count() > d->m_maxItems) {
         delete removeAction(selectableActionGroup()->actions().last());
     }
 }
@@ -141,6 +139,12 @@ static QString titleWithSensibleWidth(const QString &nameValue, const QString &v
 void KRecentFilesAction::addUrl(const QUrl &_url, const QString &name)
 {
     Q_D(KRecentFilesAction);
+
+    // ensure we never add items if we want none
+    if (d->m_maxItems == 0) {
+        return;
+    }
+
     /**
      * Create a deep copy here, because if _url is the parameter from
      * urlSelected() signal, we will delete it in the removeAction() call below.
@@ -176,7 +180,8 @@ void KRecentFilesAction::addUrl(const QUrl &_url, const QString &name)
         }
     }
     // remove oldest item if already maxitems in list
-    if (d->m_maxItems && selectableActionGroup()->actions().count() == d->m_maxItems) {
+    Q_ASSERT(d->m_maxItems > 0);
+    if (selectableActionGroup()->actions().count() == d->m_maxItems) {
         // remove oldest added item
         delete removeAction(selectableActionGroup()->actions().first());
     }
@@ -230,7 +235,7 @@ QList<QUrl> KRecentFilesAction::urls() const
 void KRecentFilesAction::clear()
 {
     clearEntries();
-    emit recentListCleared();
+    Q_EMIT recentListCleared();
 }
 
 void KRecentFilesAction::clearEntries()
@@ -250,12 +255,12 @@ void KRecentFilesAction::loadEntries(const KConfigGroup &_config)
     Q_D(KRecentFilesAction);
     clearEntries();
 
-    QString     key;
-    QString     value;
-    QString     nameKey;
-    QString     nameValue;
-    QString      title;
-    QUrl        url;
+    QString key;
+    QString value;
+    QString nameKey;
+    QString nameValue;
+    QString title;
+    QUrl url;
 
     KConfigGroup cg = _config;
     if (cg.name().isEmpty()) {
@@ -308,8 +313,8 @@ void KRecentFilesAction::loadEntries(const KConfigGroup &_config)
 void KRecentFilesAction::saveEntries(const KConfigGroup &_cg)
 {
     Q_D(KRecentFilesAction);
-    QString     key;
-    QString     value;
+    QString key;
+    QString value;
     QStringList lst = items();
 
     KConfigGroup cg = _cg;
@@ -323,13 +328,12 @@ void KRecentFilesAction::saveEntries(const KConfigGroup &_cg)
     for (int i = 1; i <= selectableActionGroup()->actions().count(); i++) {
         key = QStringLiteral("File%1").arg(i);
         // i - 1 because we started from 1
-        value = d->m_urls[ selectableActionGroup()->actions()[ i - 1 ] ].toDisplayString(QUrl::PreferLocalFile);
+        value = d->m_urls[selectableActionGroup()->actions()[i - 1]].toDisplayString(QUrl::PreferLocalFile);
         cg.writePathEntry(key, value);
         key = QStringLiteral("Name%1").arg(i);
-        value = d->m_shortNames[ selectableActionGroup()->actions()[ i - 1 ] ];
+        value = d->m_shortNames[selectableActionGroup()->actions()[i - 1]];
         cg.writePathEntry(key, value);
     }
-
 }
 
 #include "moc_krecentfilesaction.cpp"
